==> haskell-foldl-1.4.18-87.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 foldl
version:              1.4.18
visibility:           public
id:                   foldl-1.4.18-DnwxI7jar0n9jaHnbNBdzr
key:                  foldl-1.4.18-DnwxI7jar0n9jaHnbNBdzr
license:              BSD-3-Clause
copyright:            2013 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.

category:             Control
abi:                  c03bb582aa701b43c8d11b9dc2939d39
exposed:              True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.NonEmpty
    Control.Foldl.Text Control.Scanl

hidden-modules:
    Control.Foldl.Optics Control.Foldl.Internal
    Control.Foldl.Util.Vector Control.Foldl.Util.MVector

import-dirs:          /usr/lib/ghc-9.6.6/site-local/foldl-1.4.18
library-dirs:         /usr/lib/ghc-9.6.6/site-local/foldl-1.4.18
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/foldl-1.4.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-foldl
hs-libraries:         HSfoldl-1.4.18-DnwxI7jar0n9jaHnbNBdzr
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot containers-0.6.7
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html:         /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foldl-1.4.18-88-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 foldl
version:              1.4.18
visibility:           public
id:                   foldl-1.4.18-c4zLrEmO0CGifNSU6CYor
key:                  foldl-1.4.18-c4zLrEmO0CGifNSU6CYor
license:              BSD-3-Clause
copyright:            2013 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.

category:             Control
abi:                  b28469fd056fe8671670b6e794d60420
exposed:              True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.NonEmpty
    Control.Foldl.Text Control.Scanl

hidden-modules:
    Control.Foldl.Optics Control.Foldl.Internal
    Control.Foldl.Util.Vector Control.Foldl.Util.MVector

import-dirs:          /usr/lib/ghc-9.6.6/site-local/foldl-1.4.18
library-dirs:         /usr/lib/ghc-9.6.6/site-local/foldl-1.4.18
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/foldl-1.4.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-foldl
hs-libraries:         HSfoldl-1.4.18-c4zLrEmO0CGifNSU6CYor
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL containers-0.6.7
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html:         /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
